##  Regular Password Rules
Requirements for passwords following regular password rules:
  * The minimum password length is eight characters.
  * The password includes at least two elements from the following character groups:
    * Lowercase letters (a-z)
    * Uppercase letters (A-Z)
    * Numerical values (0-9)
    * Special characters (!, ", $, ...)
